@@ -32,8 +32,7 @@ class PyGs(object):
     """Class to wrap all the ghostscript calls"""
     def __init__(self):
         # Detect windows gs binary (make this smarter in the future)
-        if os.name == 'nt':
-            #self.binary = 'start /wait "gs" "c:\\Program Files (x86)\\gs\\gs9.07\\bin\\gswin32c.exe"'
+        if str(os.name) == 'nt':
             self.binary = '"c:\\Program Files (x86)\\gs\\gs9.07\\bin\\gswin32c.exe"'
         else:
             self.binary = "gs"
@@ -41,19 +40,13 @@ class PyGs(object):
         self.gs_options = {'tiff': ['-sDEVICE=tiff24nc','-r%d' % (self.tiff_dpi)],
                             'jpg': ['-sDEVICE=jpeg','-dJPEGQ=75', '-r200']
                         }
+        self.msgs = {
+                'GS_FAILED': 'Ghostscript execution failed',
+                'GS_MISSING_PDF': 'Cannot find specified pdf file',
+            }
 
-    def make_img_from_pdf(self, pdf_filename, output_format):
-        # Need tiff for multi-page documents
-        if not os.path.exists(pdf_filename):
-            error("Cannot find specified pdf file %s" % (pdf_filename))
-
-        filename, filext = os.path.splitext(pdf_filename)
-        output_filename = "%s.%s" % (filename, output_format)
-
-        logging.info("Running ghostscript on %s to create %s" % (pdf_filename, output_filename))
-
-        options = ' '.join(self.gs_options[output_format])
-        if os.name=='nt':
+    def _run_gs(self, options, output_filename, pdf_filename):
+        if str(os.name)=='nt':
             cmd = '%s -q -dNOPAUSE %s -sOutputFile="%s" "%s" -c quit' % (self.binary, options, output_filename, pdf_filename)
             logging.info(cmd)        
             ret = subprocess.call(cmd)
@@ -63,23 +56,27 @@ class PyGs(object):
             ret = os.system(cmd)
 
         if ret != 0:
-            error ("Ghostscript execution failed!")
+            error (self.msgs['GS_FAILED'])
+
+    def make_img_from_pdf(self, pdf_filename, output_format):
+        # Need tiff for multi-page documents
+        if not os.path.exists(pdf_filename):
+            error(self.msgs['GS_MISSING_PDF'] + " %s" % pdf_filename)
+
+        filename, filext = os.path.splitext(pdf_filename)
+        output_filename = "%s.%s" % (filename, output_format)
+
+        logging.info("Running ghostscript on %s to create %s" % (pdf_filename, output_filename))
+
+        options = ' '.join(self.gs_options[output_format])
+        self._run_gs(options, output_filename, pdf_filename)
+
         logging.info("Created %s" % output_filename)
 
         # Create ancillary jpeg files per page to get around the fact
         # that reportlab doesn't compress PIL images, leading to huge PDFs
         # Instead, we insert the jpeg directly per page
         options = ' '.join(self.gs_options['jpg'])
-        if os.name == 'nt':
-            cmd = '%s -q -dNOPAUSE %s -sOutputFile="%s%%d.jpg" "%s" -c quit' % (self.binary, options, filename, pdf_filename)
-            logging.info(cmd)        
-            ret = subprocess.call(cmd)
-        else:
-            cmd = '%s -q -dNOPAUSE %s -sOutputFile="%s%%d.jpg" "%s" -c quit' % (self.binary, options, filename, pdf_filename)
-            logging.info(cmd)        
-            ret = os.system(cmd)
-            
-        if ret != 0:
-            error ("Ghostscript execution failed!")
+        self._run_gs(options, "%s%%d.jpg" % filename, pdf_filename)
         return (self.tiff_dpi,output_filename)
 
